@@ -1,5 +1,5 @@
 from .client import Client
-from labelpandas.rename_columns import rename_columns
-from .load_local_files import load_local_files
 from labelpandas import connector
 from labelpandas import uploader
+from labelpandas.rename_columns import rename_columns
+from labelpandas.load_local_files import load_local_files
